/*
assemble_sample.do
by: Attila Gyetvai

assembles the cleaned data set on the server
*/


use "${path_build_aux}/displaced.dta", clear


*-- predisplacement measures
* merge firm characteristics
merge 1:1 anon t using "${path_raw_data}/nav_eredeti.dta", keep(match master) ///
	keepusing(teaor08_1) nogen
ren teaor08_1 indust_1
gsort anon t

* 5y history flag
gen hist5y = 0
forval tt = 1/60 {
	replace hist5y = 1 if displaced[_n+`tt'-1]
}

* 1y history flag
gen hist1y = 0
tempvar firm_disp
gen `firm_disp' = .
forval tt = 1/12 {
	replace hist1y = 1 if displaced[_n+`tt'-1]
	replace `firm_disp' = firm[_n+`tt'-1] if displaced[_n+`tt'-1]
}

* predisplacement wage
bysort anon (t): gegen w_pre = mean(log(w_1)) if (hist1y) & firm==`firm_disp'

* predisplacement wage growth
bysort anon (t): gen w_growth = w_1/w_1[_n-1] - 1
gquantiles w_growth_pct = w_growth, xtile n(100)
gen w_growth_win = w_growth    // winsorize wage growth at 1%
su w_growth if w_growth_pct==2
local w_growth_pct2_min r(min)
replace w_growth_win = `w_growth_pct2_min' if w_growth_pct==1
su w_growth if w_growth_pct==99
local w_growth_pct99_max r(max)
replace w_growth_win = `w_growth_pct99_max' if w_growth_pct==100
bysort anon (t): gegen w_growth_pre = mean(w_growth_win) if (hist5y)
drop w_growth w_growth_pct w_growth_win

* predisplacement U rate
bysort anon (t): gegen ur_pre = mean(1-E) if (hist5y)

* avg firm size
tempvar log_size
gen `log_size' = log(firm_size)
bysort anon (t): gegen firm_size_pre = mean(`log_size') if (hist5y)

* sectoral experience and firm count
gsort anon firm hist5y t
bysort anon firm (hist5y t): gegen firm_tenure = count(_n) if (hist5y)
bysort anon firm (hist5y t): gegen firm_count_pre = count(_n==1) if (hist5y)
gsort anon t
replace firm_tenure = . if missing(firm)
tempvar tmp_ft firm_tenure_max
bysort anon (t): gegen `firm_tenure_max' = max(firm_tenure)
gen `tmp_ft' = indust_1 if `firm_tenure_max'==firm_tenure
bysort anon t: gegen sec_exp = max(`tmp_ft')


*-- outcomes
* reentry
tempvar tmp1 tmp2
gen `tmp1' = t if displaced
bysort anon (t): gegen t_displaced = max(`tmp1')
bysort anon (t): gegen `tmp2' = min(t) if (E) & t>t_displaced
bysort anon (t): gegen t_reentry = max(`tmp2')

* U duration after displacement
gen durU = t_reentry - t_displaced - 1
qui su t
replace durU = `r(max)' - t_displaced - 1 if missing(t_reentry) & !missing(t_displaced)
gen durU_cens = missing(t_reentry) & !missing(t_displaced)

* Pr(finding a job within mm months)
qui su durU
forval mm=0/`r(max)' {
	gen job`mm'm_post = durU<=`mm'
}

* wage at reentry
merge m:1 t using "${path_build_aux}/inflation.dta", keep(match master) nogen
gen lnrw = ln(w/CoreInflIndex)
tempvar tmpw
gen `tmpw' = lnrw if t==t_reentry
bysort anon (t): gegen lnrw_post = max(`tmpw')

* full time status at reentry
tempvar tmps
gen `tmps' = (status>=201 & status<=205) if t==t_reentry
bysort anon (t): gegen fulltime_post = max(`tmps')

* Pr(staying in same occupation)
tempvar tmpod tmpor
gen `tmpod' = occ_4 if t==t_displaced
bysort anon (t): gegen occ_disp = max(`tmpod')
gen `tmpor' = occ_4 if t==t_reentry
bysort anon (t): gegen occ_post = max(`tmpor')
gen occstay_post = occ_post==occ_disp if !missing(occ_post) & !missing(occ_disp)

* tenure at first job after reentry
tempvar tmp1 tmp2 tmp3 tmpt
gen `tmp1' = 1 if t==1
replace `tmp1' = 1 if (EU | UE | JJ)
bysort anon (t): gen `tmp2' = sum(`tmp1')
bysort anon `tmp2' (t): gen `tmp3' = _N
gen `tmpt' = `tmp3' if t==t_reentry
bysort anon (t): gegen tenure_post = max(`tmpt')

* change in AKM firm/match FE
preserve
drop if missing(firm)
gen age1 = age-40    // following CCHK (2018)
gen age2 = age1^2
gen age3 = age1^3
egen anonfirm = group(anon firm)
reghdfe lnrw age1 age2 age3, absorb(anonfirmfe=anonfirm)
drop if missing(anonfirmfe)
gduplicates drop anon firm anonfirmfe, force
reghdfe anonfirmfe, absorb(anonfe=anon firmfe=firm) res(matchfe)
drop if missing(firmfe)
keep anon anonfe firm firmfe matchfe
save "${path_build_aux}/fe.dta", replace
restore
merge m:1 anon firm using "${path_build_aux}/fe.dta", keep(match master) nogen
gsort anon t
tempvar tmpffed tmpffer tmpmfed tmpmfer
gen `tmpffed' = firmfe if t==t_displaced
bysort anon (t): gegen firmfe_disp = max(`tmpffed')
gen `tmpffer' = firmfe if t==t_reentry
bysort anon (t): gegen firmfe_post = max(`tmpffer')
gen `tmpmfed' = matchfe if t==t_displaced
bysort anon (t): gegen matchfe_disp = max(`tmpmfed')
gen `tmpmfer' = matchfe if t==t_reentry
bysort anon (t): gegen matchfe_post = max(`tmpmfer')
gen dfirmfe = firmfe_post - firmfe_disp
gen dmatchfe = matchfe_post - matchfe_disp


*-- save sample
keep if (displaced)
local vars "anon t age female occ_4 firm firm_tenure w_pre w_growth_pre ur_pre firm_size_pre firm_count_pre sec_exp durU durU_cens job*m_post lnrw_post fulltime_post occstay_post tenure_post dfirmfe dmatchfe"
keep `vars'
order `vars'

* merge network measures
merge 1:1 anon t using "${path_build_aux}/network_measures.dta", keep(match) nogen

* remove var labels
foreach var of varlist _all {
	la var `var'
}
cap drop __0*

save "${path_build_aux}/sample_server.dta", replace


*-- end code
