/*
patchit.do
by: Istvan Boza
modified by: Attila Gyetvai

this script identifies gaps in employment spells by 1st and/or 2nd 
employment statuses and fills them if possible.

1. identify monthly and yearly gaps
2. if anon works at same firm before and after gap, fill with that info
*/

* confirm that master data set is loaded
cap gen month = mod(t,12)
replace month = 12 if month==0
confirm var anon t month year firm_1 firm_2 transfer_1

* define vars to patch
global vvpatch "firm_"

* identify gaps
gen topatch = missing(firm_1) & missing(transfer_1)


*-- monthly gaps
gen patch1 = 0
bysort anon (t): replace patch1 = 1 if topatch[_n]==1 & topatch[_n-1]==0 & topatch[_n+1]==0

* check if possible to fill
gen tofill1 = 0 if patch1==1
bysort anon (t): replace tofill1 = 1 if !missing(firm_1[_n-1]) & !missing(firm_1[_n+1]) & patch1==1

* generate fill types
/* possible fills:
	A: firm_1[t-1]==firm_1[t+1]
	B: firm_2[t-1]==firm_2[t+1]
	C: firm_1[t-1]==firm_2[t+1]    (if firm 2 pays more than 1 after gap)
	D: firm_2[t-1]==firm_1[t+1]    (if firm 1 pays more than 2 after gap)
	E: A and B
	F: C and D
*/
gen f_A = 1 if tofill1==1 & firm_1[_n-1]==firm_1[_n+1] & anon[_n-1]==anon[_n+1] & !missing(firm_1[_n-1])
gen f_B = 1 if tofill1==1 & firm_2[_n-1]==firm_2[_n+1] & anon[_n-1]==anon[_n+1] & !missing(firm_2[_n-1])
gen f_C = 1 if tofill1==1 & firm_1[_n-1]==firm_2[_n+1] & anon[_n-1]==anon[_n+1] & !missing(firm_1[_n-1])
gen f_D = 1 if tofill1==1 & firm_2[_n-1]==firm_1[_n+1] & anon[_n-1]==anon[_n+1] & !missing(firm_2[_n-1])

gen str f_1 = ""
replace f_1 = "A" if f_A==1 & f_B!=1
replace f_1 = "B" if f_A!=1 & f_B==1
replace f_1 = "C" if f_C==1 & f_D!=1
replace f_1 = "D" if f_C!=1 & f_D==1
replace f_1 = "E" if f_A==1 & f_B==1
replace f_1 = "F" if f_C==1 & f_D==1
drop f_A-f_D
drop tofill1

* fill monthly gaps
gen filled1 = 0

* A: firm_1[t-1]==firm_1[t+1]
foreach v of global vvpatch {
	replace `v'1 = `v'1[_n-1] if f_1=="A"
}
replace filled1 = 1 if f_1=="A"
 
* B: firm_2[t-1]==firm_2[t+1]    // firm 2 becomes 1 since 1 is missing
foreach v of global vvpatch {
	replace `v'1 = `v'2[_n-1] if f_1=="B"
}
replace filled1 = 1 if f_1=="B"

* C: firm_1[t-1]==firm_2[t+1]    // fill with previous firm 1
foreach v of global vvpatch {
	replace `v'1 = `v'1[_n-1] if f_1=="C"
}
replace filled1 = 1 if f_1=="C"

* D: firm_2[t-1]==firm_1[t+1]    // firm 2 becomes 1
foreach v of global vvpatch {
	replace `v'1 = `v'2[_n-1] if f_1=="D"
}
replace filled1 = 1 if f_1=="D"

* E: A and B
foreach v of global vvpatch {
	replace `v'1 = `v'1[_n-1] if f_1=="E"
	replace `v'2 = `v'2[_n-1] if f_1=="E"
}
replace filled1 = 1 if f_1=="E"

* F: C and D    // firm 1 and 2 switches
foreach v of global vvpatch {
	replace `v'1 = `v'2[_n-1] if f_1=="F"
	replace `v'2 = `v'1[_n-1] if f_1=="F"
}
replace filled1 = 1 if f_1=="F"

drop f_1


*-- yearly gaps (Jan to Dec)
gen patch12A = 0
bysort anon (t): replace patch12A = 1 if topatch[_n]==1 & topatch[_n-1]==0 & topatch[_n+12]==0 ///
	& month==1 & topatch[_n+1]==1 & topatch[_n+2]==1 & topatch[_n+3]==1 & topatch[_n+4]==1 ///
	& topatch[_n+5]==1 & topatch[_n+6]==1 & topatch[_n+7]==1 & topatch[_n+8]==1 ///
	& topatch[_n+9]==1 & topatch[_n+10]==1 & topatch[_n+11]==1 
bysort anon year (t): gen patch12 = patch12A[1]
drop patch12A topatch

* check if possible to fill
gen tofill12A = 0 if patch12==1
bysort anon (t): replace tofill12A = 1 if !missing(firm_1[_n-1]) & !missing(firm_1[_n+12]) ///
	& month==1 & patch12==1
bysort anon year (t): gen tofill12 = tofill12A[1]
drop tofill12A patch12

* generate fill types
/* possible fills:
	A: firm_1[t-1]==firm_1[t+12]
	B: firm_2[t-1]==firm_2[t+12]
	C: firm_1[t-1]==firm_2[t+12]    (if firm 2 pays more than 1 after gap)
	D: firm_2[t-1]==firm_1[t+12]    (if firm 1 pays more than 2 after gap)
	E: A and B
	F: C and D
*/
gen f_A = 1 if tofill12==1 & firm_1[_n-1]==firm_1[_n+12] & anon[_n-1]==anon[_n+12] ///
	& month==1 & !missing(firm_1[_n-1])
gen f_B = 1 if tofill12==1 & firm_2[_n-1]==firm_2[_n+12] & anon[_n-1]==anon[_n+12] ///
	& month==1 & !missing(firm_2[_n-1])
gen f_C = 1 if tofill12==1 & firm_1[_n-1]==firm_2[_n+12] & anon[_n-1]==anon[_n+12] ///
	& month==1 & !missing(firm_1[_n-1])
gen f_D = 1 if tofill12==1 & firm_2[_n-1]==firm_1[_n+12] & anon[_n-1]==anon[_n+12] ///
	& month==1 & !missing(firm_2[_n-1])

gen str f_12A = ""
replace f_12A = "A" if f_A==1 & f_B!=1
replace f_12A = "B" if f_A!=1 & f_B==1
replace f_12A = "C" if f_C==1 & f_D!=1
replace f_12A = "D" if f_C!=1 & f_D==1
replace f_12A = "E" if f_A==1 & f_B==1
replace f_12A = "F" if f_C==1 & f_D==1
drop f_A-f_D
drop tofill12
bysort anon year (t): gen f_12 = f_12A[1]
drop f_12A

* fill yearly gaps (Jan first, other months after)
gen filled12 = 0

* A: firm_1[t-1]==firm_1[t+12]
foreach v of global vvpatch {
	replace `v'1 = `v'1[_n-1] if f_12=="A" & month==1
}
replace filled12 = 1 if f_12=="A" & month==1
 
* B: firm_2[t-1]==firm_2[t+12]    // firm 2 becomes 1 since 1 is missing
foreach v of global vvpatch {
	replace `v'1 = `v'2[_n-1] if f_12=="B" & month==1
}
replace filled12 = 1 if f_12=="B" & month==1

* C: firm_1[t-1]==firm_2[t+12]    // fill with previous firm 1
foreach v of global vvpatch {
	replace `v'1 = `v'1[_n-1] if f_12=="C" & month==1
}
replace filled12 = 1 if f_12=="C" & month==1

* D: firm_2[t-1]==firm_1[t+12]  // firm 2 becomes 1
foreach v of global vvpatch {
	replace `v'1 = `v'2[_n-1] if f_12=="D" & month==1
}
replace filled12 = 1 if f_12=="D" & month==1

* E: A and B
foreach v of global vvpatch {
	replace `v'1 = `v'1[_n-1] if f_12=="E" & month==1
	replace `v'2 = `v'2[_n-1] if f_12=="E" & month==1
}
replace filled12 = 1 if f_12=="E" & month==1

* F: C and D    // firm 1 and 2 switches
foreach v of global vvpatch {
	replace `v'1 = `v'2[_n-1] if f_12=="F" & month==1
	replace `v'2 = `v'1[_n-1] if f_12=="F" & month==1
}
replace filled12 = 1 if f_12=="F" & month==1
drop f_12

* fill months Feb-Dec
rename filled12 pt_id
bysort anon year (t): gen filled12 = pt_id[1]
drop pt_id

foreach v of global vvpatch {
	bysort anon year (t): replace `v'1 = `v'1[1] if filled12==1
	bysort anon year (t): replace `v'2 = `v'2[1] if filled12==1
}


*-- end code
