/*
clean_sample.do
by: Attila Gyetvai

cleans the sample and saves the final dataset
*/


*-- initialize
use "${path_build_aux}/sample_server.dta", clear


*-- network employment rate
* missing values: replace with 0 and include indicator in regressions
foreach sd in "" _same1 _diff1 _same2 _diff2 _same3 _diff3 _same4 _diff4 {
	foreach ro in "" _rcnt12 _oldr12 _rcnt24 _oldr24 {
		gen mis`sd'`ro' = missing(er`sd'`ro')
		replace er`sd'`ro'  = 0 if mis`sd'`ro'
	}
}

* nested network employment rate
foreach ro in "" _rcnt12 _oldr12 _rcnt24 _oldr24 {
	gen N_same4x`ro' = N_same4`ro'
	drop if N_same4x`ro'<0
	gen er_same4x`ro' = er_same4`ro'
	
	forval od=1/3 {
		local od1 = `od'+1
		gen N_same`od'x`ro' = N_same`od'`ro' - N_same`od1'`ro'
		drop if N_same`od'x`ro'<0
		gen er_same`od'x`ro' = (round(er_same`od'`ro'*N_same`od'`ro') ///
			- round(er_same`od1'`ro'*N_same`od1'`ro')) ///
			/ N_same`od'x`ro'    // rounding to get integer num employed
		gen mis`od'x`ro' = missing(er_same`od'x`ro')
		replace er_same`od'x`ro' = 0 if mis`od'x`ro'
		drop if (er_same`od'x`ro'<0) | (er_same`od'x`ro'>1)
	}
}


*-- network size
* take logs
foreach sd in "" _same1 _same2 _same3 _same4 _same1x _same2x _same3x _same4x _diff1 _diff2 _diff3 _diff4 {
	foreach ro in "" _rcnt12 _oldr12 _rcnt24 _oldr24 {
		gen logN`sd'`ro' = log(N`sd'`ro' + 1)
	}
}

* shares
forval od=1/4 {
	gen Nsh_same`od' = N_same`od'/N
	gen Nsh_same`od'x = N_same`od'x/N
}


*-- average AKM FEs in network
merge m:1 anon using "${path_build_aux}/network_fe.dta", keep(match master) nogen


*-- outcomes
* log unemployment duration
gen u = log(durU+1)

* job finding probability
cap drop job*m_post
qui su durU
forval mm=0/`r(max)' {
	gen job`mm'm_post = durU<=`mm'
}


*-- controls
* predisplacement occ FEs
egen eta_1 = group(occ_1)
egen eta_2 = group(occ_2)
egen eta_3 = group(occ_3)
egen eta_4 = group(occ_4)

* closing firm FEs
egen lambda = group(firm)

* age
gen age2 = age^2

* tenure
ren firm_tenure tenure
gen tenure2 = tenure^2

* 2-digit sector FEs
tempvar tmpsec
gen `tmpsec' = floor(sec_exp/100)
egen sec_pre = group(`tmpsec')
replace sec_pre = 0 if missing(sec_exp)

* num employers prior to displacement
gen firm_count_pre_cat_1 = firm_count_pre==1
gen firm_count_pre_cat_2 = firm_count_pre==2
gen firm_count_pre_cat_3 = firm_count_pre==3

* education
cap gen educ = .
replace educ = 4 if occ_1==1 | occ_1==2
replace educ = 3 if occ_3==133
replace educ = 3 if occ_1==3
replace educ = 1 if occ_1==9
replace educ = 2 if missing(educ) & !missing(occ_1) & occ_1!=0
replace educ = 3 if educ==4    // merge college and HS

* calendar year
gen year = .
replace year = 2008 if t>=61 & t<=72
replace year = 2009 if t>=73 & t<=84
replace year = 2010 if t>=85 & t<=96

* sectoral prevalence
bysort occ_4 sec_pre: gegen occ_sec_preval = count(anon)
replace occ_sec_preval = . if missing(occ_4)
replace occ_sec_preval = . if sec_pre==0
gsort t anon


*-- equalize sample size
* controls
local Xd "female age age2 tenure tenure2"
local Xi "w_pre w_growth_pre ur_pre"
local Xj "firm_size_pre firm_count_pre_cat_*"

* regression
local om 4
tempvar tmp1 tmpflag
reghdfe u er_diff`om' er_same`om' logN_diff`om' logN_same`om' mis_same`om' mis_diff`om' `Xd' `Xi' `Xj', absorb(`tmp1'=lambda sec_pre) vce(r)
gen `tmpflag' = !missing(`tmp1')
keep if `tmpflag'


*-- save sample
* labels
la var u "Log unemployment duration"
la var job12m_post "Pr(finding a job within a year)"
la var lnrw_post "Log real wage at postdisplacement job"
la var fulltime_post "Pr(postdisplacement job is full-time)"
la var occstay_post "Pr(postdisplacement job is in same occ.)"
la var tenure_post "Tenure at postdisplacement job"
la var dfirmfe "Change in AKM firm fe"
la var dmatchfe "Change in AKM match fe"
la var er "Network employment rate"
la var logN "Log network size"
forval o=1/4 {
	la var er_diff`o' "Network employment rate, other occ."
	la var er_same`o' "Network employment rate, same occ."
	la var er_same`o'x "Network employment rate, same `o'-digit occ."
	la var logN_diff`o' "Log network size, other occ."
	la var logN_same`o' "Log network size, same occ."
}
la var anonfe_network "AKM worker FE in network"
la var matchfe_network "AKM match FE in network"
la var w_pre "Wage at displacement"
la var w_growth_pre "Predisplacement wage growth"
la var ur_pre "Predisplacement unemployment"
la var firm_size_pre "Predisplacement firm size"
forval j=1/3 {
	la var firm_count_pre_cat_`j' "Num.\ predisplacement employers -- `j'"
}

cap drop __0*

save "${path_clean}/sample.dta", replace


*-- end code
