/*
estimate_models.do
by: Attila Gyetvai

estimates the models and saves the results
*/


*-- initialize
cls
set more off
est clear

* paths
global path_root          ""    // local root directory
global path_build         "${path_root}/build"
global path_build_aux     "${path_build}/aux"
global path_calcs         "${path_root}/calcs"
global path_clean         "${path_calcs}/clean_data"
global path_results       "${path_root}/results"
global path_tables        "${path_results}/tables"
global path_graphs        "${path_results}/graphs"
cd "${path_build}"

cap log close
log using "${path_results}/estimate_models.log", replace

use "${path_clean}/sample.dta", clear

* putexcel
putexcel clear
putexcel set "${path_results}/pr_e_months.xlsx", modify
global r_i = 2    // row index for regression results; 1 is header
putexcel A1 = "er"
putexcel B1 = "er_ci_lo"
putexcel C1 = "er_ci_hi"
putexcel D1 = "ersame4"
putexcel E1 = "ersame4_ci_lo"
putexcel F1 = "ersame4_ci_hi"

* controls
local Xd "female age age2 tenure tenure2"
local Xi "w_pre w_growth_pre ur_pre"
local Xj "firm_size_pre firm_count_pre_cat_*"
local Xfe "anonfe_network matchfe_network"



// TABLES AND FIGURES IN MAIN TEXT //

*-- table 1: U duration on network employment rate
// only in 2008 so that durations are not censored
reghdfe u er logN mis `Xd' `Xi' `Xj' `Xfe' if year==2008, absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto tab1_1
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

reghdfe u er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe' if year==2008, absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto tab1_2
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace
	
esttab tab1_* using "${path_tables}/tab_1.tex", replace ///
	keep(er* logN* `Xfe' `Xi' `Xj') ///
	order(er er_same* logN logN_same* `Xfe') ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3) label( )) se(par fmt(3) label( ))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
	

*-- table 2: U duration on network employment rate, all digits together
// only in 2008 so that durations are not censored
forval od = 1/4 {
	label var logN_same`od' "Log network size, same 4-digit occ."
}
reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008, absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto tab2_1
estadd local akmfe "Y", replace
estadd local i_pre "Y", replace
estadd local j_pre "Y", replace
estadd local psfe "Y", replace
estadd local pofe "Y", replace
estadd local cffe "Y", replace

esttab tab2_* using "${path_tables}/tab_2.tex", replace ///
	keep(er* logN) ///
	order(er* logN) ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3)) se(par fmt(3))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "i_pre Pre-displacement worker characteristics" "j_pre Pre-displacement firm characteristics" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
forval od=1/4 {
	label var logN_same`od' "Log network size, same occ."
}


*-- table 3: U duration on network employment rate, by skill content
// only in 2008 so that durations are not censored
*- separate regressions
forval educ = 1/3 {
	reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & educ==`educ', absorb(lambda eta_4 sec_pre) vce(r)
	est sto tab3_`educ'
	test er_same4x er_same3x er_same2x er_same1x
	estadd scalar F_joint = r(F)
	estadd scalar p_joint = r(p)
	estadd local akmfe "Y", replace
	estadd local i_pre "Y", replace
	estadd local j_pre "Y", replace
	estadd local psfe "Y", replace
	estadd local pofe "Y", replace
	estadd local cffe "Y", replace
}

esttab tab3_* using "${path_tables}/tab_3.tex", replace ///
	keep(er* logN) ///
	order(er* logN) ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3)) se(par fmt(3))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "i_pre Pre-displacement worker characteristics" "j_pre Pre-displacement firm characteristics" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)" "F_joint Joint \(F\)-test" "p_joint \(p\)-value") ///
	sfmt(0 0 0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})

*- pooled regression across education levels, results manually exported
reghdfe u i.educ#c.(er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1) `Xd' `Xi' `Xj' `Xfe' if year==2008, absorb(lambda eta_4 sec_pre) vce(r)


*-- figure 1: Pr(finding a job within X months)
qui {
	forval mm=0/46 {
		reghdfe job`mm'm_post er_diff4 er_same4 logN_diff4 logN_same4 mis_diff4 mis_same4 `Xd' `Xi' `Xj' `Xfe', ///
		absorb(lambda eta_4 sec_pre) vce(cluster firm)
		putexcel A${r_i} = _b[er_diff4]
		putexcel B${r_i} = (_b[er_diff4] + invttail(e(df_r), 0.975) * _se[er_diff4])
		putexcel C${r_i} = (_b[er_diff4] + invttail(e(df_r), 0.025) * _se[er_diff4])
		putexcel D${r_i} = _b[er_same4]
		putexcel E${r_i} = (_b[er_same4] + invttail(e(df_r), 0.975) * _se[er_same4])
		putexcel F${r_i} = (_b[er_same4] + invttail(e(df_r), 0.025) * _se[er_same4])
		global r_i = ${r_i}+1
	}
}
* plot the results saved in Excel



// TABLES IN APPENDIX A //

*-- app table A.5: Pr(finding a job within 1 month) on network employment rate
reghdfe job1m_post er logN mis `Xd' `Xi' `Xj' `Xfe', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto atab5_1
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

reghdfe job1m_post er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto atab5_2
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace
	
esttab atab5_* using "${path_tables}/tab_a5.tex", replace ///
	keep(er* logN* `Xfe' `Xi' `Xj') ///
	order(er er_same* logN logN_same* `Xfe') ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3) label( )) se(par fmt(3) label( ))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
	


// TABLES IN APPENDIX B--ROBUSTNESS //

*-- app table B.1: replicate table 1 excluding large networks
// only in 2008 so that durations are not censored
_pctile N, p(99)
reghdfe u er logN mis `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto btab1_1
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

_pctile N, p(99)
reghdfe u er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto btab1_2
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace
	
esttab btab1_* using "${path_tables}/tab_b1.tex", replace ///
	keep(er* logN* `Xfe' `Xi' `Xj') ///
	order(er er_same* logN logN_same* `Xfe') ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3) label( )) se(par fmt(3) label( ))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
	

*-- app table B.2: replicate table 2 excluding large networks
// only in 2008 so that durations are not censored
forval od = 1/4 {
	label var logN_same`od' "Log network size, same 4-digit occ."
}
_pctile N, p(99)
reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto btab2_1
estadd local akmfe "Y", replace
estadd local i_pre "Y", replace
estadd local j_pre "Y", replace
estadd local psfe "Y", replace
estadd local pofe "Y", replace
estadd local cffe "Y", replace

esttab btab2_* using "${path_tables}/tab_b2.tex", replace ///
	keep(er* logN) ///
	order(er* logN) ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3)) se(par fmt(3))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "i_pre Pre-displacement worker characteristics" "j_pre Pre-displacement firm characteristics" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
forval od=1/4 {
	label var logN_same`od' "Log network size, same occ."
}


*-- app table B.3: replicate table 3 excluding large networks
// only in 2008 so that durations are not censored
*- separate regressions
forval educ = 1/3 {
	_pctile N, p(99)
	reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & educ==`educ' & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(r)
	est sto btab3_`educ'
	test er_same4x er_same3x er_same2x er_same1x
	estadd scalar F_joint = r(F)
	estadd scalar p_joint = r(p)
	estadd local akmfe "Y", replace
	estadd local i_pre "Y", replace
	estadd local j_pre "Y", replace
	estadd local psfe "Y", replace
	estadd local pofe "Y", replace
	estadd local cffe "Y", replace
}

esttab btab3_* using "${path_tables}/tab_b3.tex", replace ///
	keep(er* logN) ///
	order(er* logN) ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3)) se(par fmt(3))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "i_pre Pre-displacement worker characteristics" "j_pre Pre-displacement firm characteristics" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)" "F_joint Joint \(F\)-test" "p_joint \(p\)-value") ///
	sfmt(0 0 0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})

*- pooled regression across education levels, results manually exported
_pctile N, p(99)
reghdfe u i.educ#c.(er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1) `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(r)
	
	
log close


*-- end code
